@@ -14,6 +14,8 @@
 #include "ipip.h"
 #include "version.h"
 #include <stdio.h>
+#include <time.h>
+#include <string.h>
 #include <sys/types.h>
 #include <sys/time.h>
 #include <signal.h>
